#!/bin/sh
VERSION='$Id: sbc_gen.sh,v 1.24 2002/10/11 11:16:26 sesam Exp $'
# 
#  Build list of files with given arguments
#
#  Same arguments as for sbc call are expected
#
trap kill_find 1 2 3 4 5 6 15

usage () 
{
       echo $0 [-l level ] path1 path2...

}

kill_find ()
{
   kill -9 $FIND_PID
   exit 1
}

exist()
{
  if [ "$1" -a ! -f "$1" ]
  then
#          echo "There is no file '$1'" | tee -a $LOG
          return 1;
  else
          return 0;
  fi
}      

read_ini ()
{
   SM_INI=`grep -i ^sm_ini /etc/sesam2000.ini|cut -d"=" -f2`
   if [  $SM_INI ]
   then
     echo `grep -i $1 $SM_INI|cut -d"=" -f2`
   fi
}


analyze_logfiles()
{
  cpio_analyze=""
  find_analyze=""
  if [ -s "$FINDLOG" ]
  then
     find_analyze="find produced warnings"
     echo "*** find produced warnings:"
     cat $FINDLOG
  fi
  if [ "$find_analyze" -o "$cpio_analyze" ]
  then
     echo `date +"%Y-%m-%d %T"` Warning: $find_analyze $cpio_analyze >&2
     return 0
  fi
}



#----------------------
exclude_with_regex () {
  EXCLUDE_LIST=`echo $EXCLUDE_LIST|tr "," " "`
      for EXCLUDE in $EXCLUDE_LIST
        do
          FIND_EX="$FIND_EX -regex \"$EXCLUDE\" -prune -o"
        done
  if [ "$EXCLUDE_FILE" ]
  then
    if [ ! -r $EXCLUDE_FILE ]
    then
      echo `date +"%Y-%m-%d %T"` Excludefile not found
      exit 1
    else
      while read EXCLUDE
      do
        FIND_EX="$FIND_EX -regex \"$EXCLUDE\" -prune -o"
      done < $EXCLUDE_FILE
    fi
  fi
}
# End of exclude_with_regex

make_time_stamp() {
if [ $TIMESTAMP ]
then
  SWITCH=`echo $TIMESTAMP|cut -b1`
  if [ $SWITCH = "@" ]
  then
    DORIFILE=`echo $TIMESTAMP|cut -b2-`
    if [ ! -f $DORIFILE ]
    then
      echo `date +"%Y-%m-%d %T"`: Error: Timestampfile not found >&2
      exit 1
    fi
    FIND_TIME=" -newer $DORIFILE";
  else
    DORIFILE=$times_dir/TIME$$.tmp
    touch -t $TIMESTAMP $DORIFILE
    FIND_TIME=" -newer $DORIFILE"
  fi
fi
}


select_level() {
SWITCH=`echo $LEVEL|cut -b1`
case  $SWITCH in
         [fF]) LEVEL=full;
	     ;;
	 [dD]) LEVEL=diff;
               if exist ${DORIFILE}.D
                  then
	            FIND_TIME=" -newer ${DORIFILE}.D ";
                  else
                     echo `date +"%Y-%m-%d %T:"`" sbc-2059: Warning:  No timestamp file found. Doing full save" >&2
                  fi
	     ;;
	 [iI]) LEVEL=incr;
               if exist ${DORIFILE}.I
                  then
                    FIND_TIME=" -newer ${DORIFILE}.I ";
                  else
                     echo `date +"%Y-%m-%d %T:"`" sbc-2059: Warning:  No timestamp file found. Doing full save" >&2
                  fi        
	     ;;
	 [cC]) LEVEL=copy;
	     ;;
esac
LEVEL=${LEVEL:-copy}
}
# end of select_level()



#reading ini-file

if [ -r /etc/sesam2000.ini ]
  then
    bin_dir=`read_ini gv_ro_bin`
    times_dir=`read_ini gv_rw_sbc_times`
    log_dir=`read_ini gv_rw_sbc_log`
    work_dir=`read_ini gv_rw_work`
  fi

bin_dir=${bin_dir:-/sesam}
work_dir=${work_dir:-/sesam/work}
log_dir=${log_dir:-/sesam/log}
times_dir=${times_dir:-/sesam/times}

PATH=$bin_dir:$work_dir:$PATH;export PATH

[ -d $times_dir ] || mkdir -p $times_dir


# shift one parameter because $0 is sbc !
shift

# getting all option. All options not needed for sbc_gen.sh are set to $x

while getopts bl:O:i:j:t:f:d:S:s:v:P:T:X:x:n:L:C:F:A opt
do
      case $opt in
         l) LEVEL=$OPTARG;;
         j) JOBNAME=$OPTARG;;
         X) EXCLUDE_FILE=$OPTARG;;
	 x) EXCLUDE_LIST=$OPTARG;;
	 f) FILE_LIST=$OPTARG;;
         T) TIMESTAMP=$OPTARG;;
	 S) x=$OPTARG;;
	 d) x=$OPTARG;;
         v) x=$OPTARG;;
         s) x=$OPTARG;;
	 t) x=$OPTARG;;
	 i) x=$OPTARG;;
	 L) x=$OPTARG;;
	 C) x=$OPTARG;;
	 O) x=$OPTARG;;
	 F) x=$OPTARG;;
	 \?) usage
            exit 1;;

      esac
done
shift `expr $OPTIND - 1`

BACKSRC=$*

DORIFILE=$times_dir/$JOBNAME

select_level
make_time_stamp


# building exclude for find. Could be read from file (-X) or commandline (-x)
# exclude_with_regex

# reading backupsources from a file
if [ "$FILE_LIST" ]
then
  if [ ! -r $FILE_LIST ]
  then
    echo `date +"%Y-%m-%d %T"` Error: Filelist $FILE_LIST not found
    exit 1
  else
    while read FILEPATH
    do
      BACKSRC=$BACKSRC" "$FILEPATH
      done < $FILE_LIST
    fi
fi


cd /  # Startpoint is root

# check if backup source == all then backup whole system

if echo $BACKSRC | grep -i ^all >/dev/null
  then
    echo `date +"%Y-%m-%d %T:"`" sbc-3063: Info:      Try to backup all local filesystems:" $BACKSRC >&2
       BACKSRC="/"        # source is root
       FIND_POINT="./"    # call with relativ path
       if [ `uname` = "SCO_SV" ]
       then
         FIND_EX=" ! -local -prune -o $FIND_EX"    # get all files exclude nfs devices
       else 
         FIND_EX=" -fstype nfs -prune -o $FIND_EX"    # get all files exclude nfs devices
       fi  
       FIND_PATH=$FIND_POINT
    elif echo $BACKSRC | grep "," >/dev/null
       then
          echo `date +"%Y-%m-%d %T:"`" sbc-3063: Info:     Try to backup multiple directories": $BACKSRC >&2
          FIND_POINT=""
          BACKSRC="${BACKSRC},EOF"
          while [ "$BACKSRC" != "EOF" ]
            do
              PARTSRC=`echo $BACKSRC | cut -f1 -d "," `
              BACKSRC=`echo $BACKSRC | cut -f2- -d ","`
              FIND_PATH=$FIND_PATH" ."$PARTSRC
                if [ ! -f "$PARTSRC"  -a  ! -d "$PARTSRC" ]
                  then
                    echo `date +"%Y-%m-%d %T:"`" sbc-1118: Error:    "$PARTSRC not existent >&2
                    exit 1
                fi
          done
          FIND_EX=" -xdev "
          BACKSRC="/"
       else
         echo `date +"%Y-%m-%d %T:"`" sbc-3062: Info:     Try to backup: $BACKSRC" >&2
           for BACKUP_PATH in $BACKSRC
             do
               BACKUP_PATH="."$BACKUP_PATH
               if [ ! -e "$BACKUP_PATH" ]
                then
                  echo `date +"%Y-%m-%d %T:"`" sbc-1118 Error:    "$BACKUP_PATH not existent >&2
                  exit 1
                fi
                FIND_PATH=$FIND_PATH" "$BACKUP_PATH
             done
          FIND_EX=" -xdev "
       fi


find $FIND_PATH $FIND_EX $FIND_TIME -print & 
FIND_PID=$! 
wait
echo EOF

