# Version  : $Id: sesam_db.sql,v 1.72.2.1 2002/10/24 15:07:50 sesam Exp $ 
#            is directly written to table defaults
#
# Title    : Database for SEP sesam2000
# File     : sesam_db.sql
# Author   : P.Schlegel / E.Einwanger  SEP Elektronik D83629 Weyarn
# Date     : 4.2.1999 11:36
# 
# History  : Derived from Version for SESAMG (VMS GUI Version 5.04)
#
# ============================================================================

# ----------------------------------------------------------------------------
# 17.01.2001 task char[15] => task char[32]
# 17.01.2001 saveset[20] => saveset char[32]
# 13.02.2001 loader_contents.int_drive nach media.init_drive verschoben
# 14.02.2001 restore_results.num und restore_tasks.num entfernt
# 24.04.2001 - Spalte media_pool CHAR(16) in Tabelle results eingebaut
#            - Spalte backup_cmd CHAR(20) in Tabelle results eingebaut
#            - Siehe Thema Nr.: 00092
#            - Vier neue Spalten in Tabelle params_fix eingebaut (typ,version,inst_date,update_date)
#            - clients_premit => clients_permit umbenannt
# 27.04.2001 Tabelle sessions erstellt
# 04.05.2001 - clients_permit => permit umbenannt
# 08.05.2001 - Primary Key task_types.backup_type um NOT NULL erweitert
# 21.05.2001 - tasks.options entfernt; task_types.source_prefix ergnzt
# 22.05.2001 - hw_drives.timeout und restore_tasks.r_prepost ergnzt
# 23.05.2001 - servers.rmi_port ergnzt
# 05.07.2001 - restore_tasks um Column eol erweitert
# 17.12.2001 - in defaults auch user_name als PRIM KEY
# 17.12.2001 - schedules *i offset integer -> Thema 00011
# 20.12.2001 - wegen POSTGRES: schedules.offset -> schedules.day_offset
# 15.01.2002 - mediapools_events.drive darf auch NULL sein
# 24.01.2002 - PSL: *i results.source, backup_type, restore_options
# 25.01.2002 - PSL: *i restore_tasks.options
# 29.01.2002 - PSL: Bugfix zu 24.1.2002 results.source war doppelt
# 30.01.2002 - EE:  *i cal_sheets.priority
# 30.01.2002 - PSL: *i params_fix.inst_cryp fr Lizenzierung
# 15.02.2002 - PSL: *i hw_drives.loader_drv,slu_id,path,block_siz,sms_nr
# 20.02.2002 - PSL: *d hw_drives.slu_id
#                   *i hw_loaders.bar_code
#                   *m hw_loaders.typ char(20) --> char(32)
# 21.02.2002 - EE: Umbenamsung hw_drives.loader_drv -> loader_drive
#                                       .block_siz  -> block_size
#                              hw_loaders.bar_code  -> barcode
# 21.02.2002 - PSL: *i clients.access_options, .stpd_options, .stpd_port
#                   *d clients.text, .slave_flg
#                    -> Thema 00024 Firewall
# 26.02.2002 - EE: *i drive_groups.restore_drive to keep default drive_num for 
#                     restore
# 12.03.2002 - EE: *d hw_drives.scsi_id deleted
# 18.03.2002 - EE: *d hw_drives.intern_dn deleted  (== loader_drive)
# 02.05.2002 - EE: *i restore_tasks/_results.reloc_source CHAR(255)
#                  *m restore_tasks/_results.target CHAR(255)
#                  *m restore_tasks/_results.filter CHAR(255)
#                  *m restore_results.size CHAR(32)
#                  *i restore_results.options CHAR(64)
# 08.05.2002 - EE: *i new table accounts 
# 06.06.2002 - EE: *i task/newday/mediapools/command/restore_events.suppress
#                  *i accounts.service_location CHAR(64)  ("local"/"server"/...)
# 11.06.2002 - EE: *i tasks/results.compress_flag and tasks/results.crypt_key
# 13.06.2002 - EE: *i cal_sheets.suppress
# 17.06.2002 - EE: *i restore_tasks/restore_results.subtask_flag CHAR(1)
#                  *i restore_tasks/restore_results.parent_task CHAR(49)
# 26.06.2002 - EE: *i tasks/results.crypt_flag CHAR(1)
# 27.06.2002 - EE: *m tasks/results.crypt_key CHAR(128)
# 11.07.2002 - EE: *i clients.sbc_version CHAR(20)
# 15.07.2002 - RS: *i drive_types.generic_typ CHAR(10)
# 31.07.2002 - PSL *i params_fix.val1 - .val4 char(128)
# 24.10.2002 - EE: *m params_fix.version CHAR(32)
# 
# ----------------------------------------------------------------------------


# ----------------------------------------------------------------------------
# Connect sesam2000 Database
# ----------------------------------------------------------------------------

connect sesam_db


########## DROP TABLES ########################

# ----------------------------------------------------------------------------
# Tables without active & passive references
# ----------------------------------------------------------------------------

drop table accounts;
drop table cal_sheets;
drop table defaults;
drop table sessions;

# ----------------------------------------------------------------------------
# Tables with only active references ( they refer to another table )
# ----------------------------------------------------------------------------

drop table terms;
drop table capacities;
drop table syntaxes;   			
drop table loader_contents;
drop table restore_users;
drop table params_fix;
drop table result_lbls;                 
drop table task_group_relations;        
drop table servers;

# ----------------------------------------------------------------------------
# Tables with active and passive references
# the sequence of drops MUST be kept due to inner relations
# ----------------------------------------------------------------------------

drop table task_events;
drop table newday_events;
drop table mediapools_events;
drop table restore_events;
drop table command_events;
drop table tasks;
drop table media;
drop table media_pools;
drop table restore_tasks;
drop table hw_drives;
drop table hw_loaders;
drop table interfaces;
drop table clients;
drop table locations;

# ----------------------------------------------------------------------------
# Tables with only passive references ( they are referred from other tables )
# ----------------------------------------------------------------------------

drop table schedules;
drop table drive_types;
drop table media_types;
drop table oper_systems;
drop table drive_groups;
drop table results;
drop table restore_results;
drop table task_groups;
drop table task_types;


########## CREATE TABLES ########################

# ----------------------------------------------------------------------------
# Tables with only passive references ( they are referred from other tables )
# ----------------------------------------------------------------------------

CREATE TABLE schedules (
	name            CHAR(30) NOT NULL PRIMARY KEY,
	cyc_flag        CHAR(1) NOT NULL,
	abs_flag        CHAR(1) NOT NULL,
	p_count         INTEGER,
	p_base          CHAR(3),
	mo              CHAR(1),
	tu              CHAR(1),
	we              CHAR(1),
	th              CHAR(1),
	fr              CHAR(1),
	sa              CHAR(1),
	su              CHAR(1),
	day_of_mth      CHAR(2),
	mth_of_yea      CHAR(2),
	wk_of_mth       CHAR(2),
	day_of_wk       CHAR(10),
	start_date      CHAR(21),
	end_date        CHAR(21),
	exec            CHAR(1),
	start_time      CHAR(5),
	duration        CHAR(5),
        day_offset      INTEGER
);

CREATE TABLE drive_types (
	drive_typ       CHAR(10) NOT NULL PRIMARY KEY,
	generic_typ     CHAR(10) NOT NULL 
);

CREATE TABLE media_types (
	media_typ       CHAR(20) NOT NULL PRIMARY KEY
);

CREATE TABLE oper_systems (
        os              CHAR(20) NOT NULL PRIMARY KEY,
        platform        CHAR(20) NOT NULL
); 

CREATE TABLE drive_groups (
	grp_id          INTEGER NOT NULL PRIMARY KEY,
	grp_name        CHAR(50),
	sms_flag        CHAR(1),
        restore_drive   INTEGER,
	text            CHAR(100)
);

CREATE TABLE results (
	saveset         CHAR(32) NOT NULL PRIMARY KEY,
        task            CHAR(32) NOT NULL,
	datum           CHAR(21) NOT NULL,
        cnt             INTEGER NOT NULL ,
	fdi_typ         CHAR(2),
	lbl_cnt         INTEGER,
	drive_num       INTEGER,
	client_id       INTEGER,
	client          CHAR(64),
	location        CHAR(50),
	source          CHAR(254),
	exclude         CHAR(254),
	start_tim       CHAR(21),
	stop_tim        CHAR(21),
        session_id      CHAR(32),
	state           CHAR(1),
	blocks          INTEGER,    
	msg             CHAR(100),
        sms_flag        CHAR(1),
        i_name          CHAR(64),
	sbc_start       CHAR(21),
	saveset_exist   CHAR(2),
        media_pool      CHAR(16),
        backup_cmd      CHAR(20),
        backup_type     CHAR(32),
        restore_options CHAR(64),
        compress_flag   CHAR(1),
        crypt_flag      CHAR(1),
        crypt_key       CHAR(128)
);

CREATE TABLE restore_results (
        start_tim       CHAR(21) NOT NULL PRIMARY KEY,
	r_task		CHAR(49) NOT NULL,
        saveset         CHAR(32) NOT NULL,
        task            CHAR(32) NOT NULL,    
        datum           CHAR(21) NOT NULL,  
        cnt             INTEGER NOT NULL,     
        rest_typ        CHAR(2) NOT NULL,      
        tree_typ        CHAR(2) NOT NULL,    
        mode            CHAR(2) NOT NULL,    
        client_id       INTEGER NOT NULL,  
        client          CHAR(64) NOT NULL,    
        target          CHAR(255) NOT NULL, 
        user_name       CHAR(30) NOT NULL,   
	subtask_flag	CHAR(1),
	parent_task	CHAR(49),
        location        CHAR(50),           
        drive_num       INTEGER,               
        i_name          CHAR(64),             
        filter          CHAR(255),             
        reloc_source    CHAR(255),             
        state           CHAR(1) NOT NULL,     
        stop_tim        CHAR(21),            
        size            CHAR(32),            
        options         CHAR(64),
        msg             CHAR(128),
	saveset_exist   CHAR(1)
);

CREATE TABLE task_groups (
        grp_name        CHAR(50) NOT NULL PRIMARY KEY,
        text            CHAR(100),
        results_sts     CHAR(1),
        prepost         CHAR(16),
        prepost_switch  CHAR(1)	
);

CREATE TABLE task_types (
        backup_type     CHAR(32) NOT NULL PRIMARY KEY,
        backup_cmd      CHAR(20),
        backup_options  CHAR(64),
        prepost         CHAR(16),
        prepost_cmd     CHAR(20),
        restore_cmd     CHAR(20),
        restore_options CHAR(64),
        r_prepost       CHAR(16),
        r_prepost_cmd   CHAR(20),
        source_prefix   CHAR(20),
        protection      CHAR(1),
        komment         CHAR(40)
);

# ----------------------------------------------------------------------------
# Tables with active and passive references
# the sequence of CREATE MUST be kept due to inner releations
# ----------------------------------------------------------------------------

CREATE TABLE restore_tasks (
	r_task		CHAR(49) PRIMARY KEY NOT NULL,
        saveset         CHAR(32) NOT NULL references results saveset,
        task            CHAR(32) NOT NULL,     
        datum           CHAR(21) NOT NULL,    
        cnt             INTEGER NOT NULL,      
        rest_typ        CHAR(2) NOT NULL, 
        tree_typ        CHAR(2) NOT NULL,
        mode            CHAR(2) NOT NULL,    
        client_id       INTEGER NOT NULL,    
        client          CHAR(64) NOT NULL, 
        target          CHAR(255) NOT NULL,         
        user_name       CHAR(30) NOT NULL,   
	subtask_flag	CHAR(1),
	parent_task	CHAR(49),
        location        CHAR(50),          
        drive_num       INTEGER,         
        i_name          CHAR(64),          
        filter          CHAR(255),
        reloc_source    CHAR(255),             
        r_prepost       CHAR(16),
	make_stamp	CHAR(21) NOT NULL,
        eol             INTEGER,
        options         CHAR(64),
	komment		CHAR(100)
);

CREATE TABLE locations (
        id              INTEGER NOT NULL PRIMARY KEY,
	name            CHAR(50),
	parent          INTEGER references locations id,
	describe        CHAR(128),
	contact         CHAR(128),
	komment         CHAR(128)
);

CREATE TABLE clients (
	client_id       INTEGER NOT NULL PRIMARY KEY,
        name            CHAR(64) NOT NULL,
	location        INTEGER references locations id,
	os              CHAR(20) NOT NULL references oper_systems os,
	net_prot        CHAR(10) NOT NULL ,
	accessmode      CHAR(10),
	komment         CHAR(80),
   	permit          CHAR(1),
        access_options  CHAR(64),
        stpd_options    CHAR(32),
        stpd_port       CHAR(32),
        sbc_version     CHAR(20)
);

CREATE TABLE hw_loaders (
	loader_num      INTEGER NOT NULL PRIMARY KEY,
	device          CHAR(30) NOT NULL,
	client_id       INTEGER NOT NULL references clients client_id,
	typ             CHAR(32) NOT NULL,
	ctrl            CHAR(10) NOT NULL,
	slots           INTEGER NOT NULL,
        drives          INTEGER,
        ports           INTEGER,
        transport       INTEGER,
        first_slot      INTEGER,
        last_slot       INTEGER,
        autounload      CHAR(1),
        barcode         CHAR(1)
);

CREATE TABLE hw_drives (
	drive_num       INTEGER NOT NULL PRIMARY KEY,
	device          CHAR(30) NOT NULL ,
	client_id       INTEGER NOT NULL references clients client_id,         
	typ             CHAR(10) NOT NULL references drive_types drive_typ,
	loader_num      INTEGER references hw_loaders loader_num,
	kompress        CHAR(1),
	sts             CHAR(132),
	msg             CHAR(132),
	occupy          CHAR(20),
	done            INTEGER,
	run             INTEGER,
	waiting         INTEGER, 
        grp_id          INTEGER references drive_groups grp_id,	
        sms_cnts        INTEGER,  
       	label           CHAR(30),
        timeout         INTEGER,
        clean_bit       CHAR(1),
        loader_drive    INTEGER,
        path            CHAR(132),
        block_size      INTEGER, 
        sms_nr          INTEGER
);

CREATE TABLE media_pools (
        name            CHAR(16) NOT NULL PRIMARY KEY,  	
        pool_id         INTEGER NOT NULL,
        descript        CHAR(80),
        drive_grp       INTEGER NOT NULL references drive_groups grp_id,
	media_strg      CHAR(3) NOT NULL,
        media_chg       CHAR(8) NOT NULL,
        disk_capac      CHAR(16),
        disk_dir        CHAR(254),
        eol             INTEGER
);

CREATE TABLE params_fix (
	kunde           CHAR(50) NOT NULL PRIMARY KEY,
	rest_eol        INTEGER NOT NULL,       
	min_free        INTEGER NOT NULL,
        typ             CHAR(20) NOT NULL,
        version         CHAR(32) NOT NULL,
        inst_date       CHAR(21) NOT NULL,
        inst_cryp       CHAR(21),
        update_date     CHAR(21) NOT NULL,
        val1            CHAR(128),
        val2            CHAR(128),
        val3            CHAR(128),
        val4            CHAR(128)
);

CREATE TABLE interfaces (
	client_id       INTEGER  NOT NULL PRIMARY KEY references clients client_id,   
        i_name          CHAR(64) NOT NULL PRIMARY KEY
);


# task_events.object references tasks.task or task_groups.grp_name

CREATE TABLE task_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          CHAR(50) NOT NULL,
        schedule        CHAR(30) NOT NULL references schedules name,
        grp_flag        CHAR(1) NOT NULL,
        priority        INTEGER NOT NULL,
        suppress        CHAR(1),
        owner           CHAR(30) NOT NULL,
        fdi_typ         CHAR(2) NOT NULL,
        media_pool      CHAR(16) NOT NULL,
        drive_num       INTEGER references hw_drives drive_num,
	i_name		CHAR(64) references interfaces i_name
);

CREATE TABLE newday_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          CHAR(16) NOT NULL references params_fix kunde,
        schedule        CHAR(30) NOT NULL references schedules name,
        priority        INTEGER NOT NULL,
        suppress        CHAR(1),
        owner           CHAR(30) NOT NULL
);

CREATE TABLE mediapools_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          CHAR(16) NOT NULL references media_pools name,
        drive           CHAR(16),
        schedule        CHAR(30) NOT NULL references schedules name,
        priority        INTEGER NOT NULL,
        suppress        CHAR(1),
        owner           CHAR(30) NOT NULL,
        grp_flag        CHAR(1) NOT NULL,
        m_count         INTEGER,
        label           CHAR(30),
        emergency       CHAR(30)
);

CREATE TABLE restore_events (
        id              INTEGER NOT NULL PRIMARY KEY,
	object		CHAR(49) UNIQUE KEY NOT NULL references restore_tasks r_task,
        schedule        CHAR(30) NOT NULL references schedules name,
        priority        INTEGER NOT NULL,
        suppress        CHAR(1),
        owner           CHAR(30) NOT NULL
);

CREATE TABLE command_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          CHAR(50) NOT NULL,
        schedule        CHAR(30) NOT NULL references schedules name,
        priority        INTEGER NOT NULL,
        suppress        CHAR(1),
        owner           CHAR(30) NOT NULL,
        type            CHAR(1) NOT NULL,
        host            CHAR(16) NOT NULL,
        user_name       CHAR(30) NOT NULL,
        command         CHAR(255) NOT NULL
);

CREATE TABLE media (
    	label           CHAR(30) NOT NULL PRIMARY KEY,
    	barcode         CHAR(30) ,   
        pool            CHAR(16) NOT NULL references media_pools name,
        id              INTEGER NOT NULL ,
	sperrkz         CHAR(1) NOT NULL ,
	sichtag         CHAR(21) NOT NULL ,
	eol             CHAR(21),
	drive_num       INTEGER references hw_drives drive_num,
        init_drive      INTEGER,
	folgekass       INTEGER,
	kasstyp         CHAR(20) NOT NULL references media_types media_typ,
	lader           INTEGER references hw_loaders loader_num,
	slot            INTEGER,
	gefuellt        INTEGER,
	eom_state       CHAR(1),
	first_init      CHAR(21),
        close_tape      CHAR(1),
	init_flag       CHAR(1),
	error           INTEGER,
	error_delt      INTEGER,
	use_count       INTEGER, 
	duplflag        CHAR(1),
	kommentar       CHAR(80)
);

CREATE TABLE tasks (
	task   	        CHAR(32) NOT NULL PRIMARY KEY,
        backup_type     CHAR(32) references task_types backup_type,
	client_id       INTEGER NOT NULL references clients client_id,
	source          CHAR(100),
	exclude         CHAR(150),
	komment         CHAR(40),		
	results_sts     CHAR(1),
	backup_options  CHAR(64),
	restore_options CHAR(64),
	prepost         CHAR(16),
        r_prepost       CHAR(16),
        nfs_mount       CHAR(1),
        filesystem      CHAR(1),
        compress_flag   CHAR(1),
        crypt_flag      CHAR(1),
        crypt_key       CHAR(128)
);

# ----------------------------------------------------------------------------
# Tables with only active references ( they refer to another table )
# ----------------------------------------------------------------------------

CREATE TABLE terms (
       id               INTEGER NOT NULL PRIMARY KEY,
       type             CHAR(1) NOT NULL,
       schedule         CHAR(30) NOT NULL references schedules name,
       next_exec        CHAR(21),
       next_end         CHAR(21)
);

CREATE TABLE capacities (
	drive_typ       CHAR(10) NOT NULL PRIMARY KEY references drive_types drive_typ,
	media_typ       CHAR(20) NOT NULL PRIMARY KEY references media_types media_typ,
	kapaz_num       INTEGER NOT NULL,
        protection      CHAR(1) NOT NULL
);

CREATE TABLE syntaxes (
	os              CHAR(20) NOT NULL PRIMARY KEY references oper_systems os,
	command         CHAR(20) NOT NULL PRIMARY KEY,
	syntax          CHAR(50) NOT NULL
);


CREATE TABLE task_group_relations (
        grp_name        CHAR(50) NOT NULL PRIMARY KEY references task_groups grp_name,
	task   	        CHAR(32) NOT NULL PRIMARY KEY references tasks task
);

CREATE TABLE result_lbls (
        saveset         CHAR(32) NOT NULL PRIMARY KEY references results saveset,
	num             INTEGER NOT NULL PRIMARY KEY,  
	label           CHAR(30) NOT NULL,
        segment         CHAR(20) NOT NULL
);

CREATE TABLE restore_users (
	name            CHAR(24) NOT NULL PRIMARY KEY,
	task            CHAR(32) NOT NULL PRIMARY KEY references tasks task,
	path            CHAR(132) NOT NULL PRIMARY KEY,
	komment         CHAR(100)
);

CREATE TABLE loader_contents (
        loader          INTEGER	NOT NULL PRIMARY KEY references hw_loaders loader_num,
        object          CHAR(10) NOT NULL PRIMARY KEY,
        number          INTEGER	NOT NULL PRIMARY KEY,
        lbl             CHAR(30),
	barcode         CHAR(30),
        check_lbl       CHAR(1),
        checkedlbl      CHAR(30),
        from_object     CHAR(10),
        from_number     INTEGER,
        to_object       CHAR(10),
        to_number       INTEGER	
);

CREATE TABLE servers (
        name            CHAR(64) NOT NULL PRIMARY KEY,
	os              CHAR(20) NOT NULL references oper_systems os,
        ip_address      CHAR(64),
        rmi_port        INTEGER,
        ctrl_port       INTEGER,
        db_port         INTEGER,
        db_name         CHAR(73),
        connect         CHAR(1),
        komment         CHAR(80)
);

# ----------------------------------------------------------------------------
# Tables without active & passive references
# ----------------------------------------------------------------------------

CREATE TABLE accounts (
        account_name       CHAR(64) NOT NULL PRIMARY KEY,
        kunde              CHAR(64),
        smtp_email_address CHAR(64) NOT NULL,
        smtp_server        CHAR(64) NOT NULL,
        mail_username      CHAR(64),
        mail_password      CHAR(64),
        mail_to            CHAR(128) NOT NULL,
        mail_cc            CHAR(128),
        mail_bcc           CHAR(128),
        service_location   CHAR(64)
);

CREATE TABLE cal_sheets (
	id		CHAR(30) PRIMARY KEY,
	start		CHAR(21),
	end_time	CHAR(21),
	ev_type		CHAR(3),
	ev_id		INTEGER,
	schedule	CHAR(30),
        priority        INTEGER,
	state		CHAR(3),
        object          CHAR(32),
        suppress        CHAR(1),
	msg		CHAR(132)
);

CREATE TABLE defaults (	
        key             CHAR(32)  NOT NULL PRIMARY KEY,
        user_name       CHAR(32)  NOT NULL PRIMARY KEY,
        value           CHAR(255) NOT NULL
);

insert into defaults values('database version','sesam','$Id: sesam_db.sql,v 1.72.2.1 2002/10/24 15:07:50 sesam Exp $' );

CREATE TABLE sessions (
	session_id      CHAR(32) PRIMARY KEY,
	object		CHAR(32),
	komment		CHAR(80)
);
