#`!$SHELL`
#
VERSION='$Id: ini2defaults.sh,v 1.2 2002/11/21 11:38:30 sesam Exp $'
#
# USAGE
usage()
{
   echo usage "$0 [all] [-u {user: default root}] [-v {0|1|2|3: default 0}]"
}
#
USER="root"
VERBOSE_LEVEL="0"
OPTIND=0
if [ "$1" = "all" ]
then
   PROCESS_ALL=1 
   shift
else
   PROCESS_ALL=0 
fi

if [ $# -gt 0 ]
then
   echo arg1 = $1
   while [ $OPTIND -le $# ]
   do
      getopts u:v:h arg
      echo arg = $arg
      case $arg in
         'u' ) USER=$OPTARG;;
         'v' ) VERBOSE_LEVEL=$OPTARG;;
         '?' | 'h' ) usage;
               exit 1;;
      esac
      #echo OPTIND = $OPTIND
      #echo OPTARG = $OPTARG
   done
   echo user = $USER
   echo verbose = $VERBOSE_LEVEL
else
   usage
fi

#
# READ INI
read_ini()
{
  SM_INI=`grep -i '^sm_ini=' /etc/sesam2000.ini|cut -d"=" -f2`
  echo `grep -i "$1=" "$SM_INI"|cut -d"=" -f2`
}
#
#
# VERBOSE
my_echo()
{
  if [ "$VERBOSE_LEVEL" -gt 0 ] 
  then
    echo $1
  fi
}
#
# ini2defaults SUBROUTINE  
ini2defaults()
{
  ini_user=$1
  echo
  echo '****' 
  echo '**** Generating defaults ini values for user' $ini_user
  echo '****' 
  echo
  my_echo "VERSION=$VERSION"

  GV_RO=`read_ini gv_ro`
  export GV_RO
  my_echo "GV_RO=$GV_RO"

  GV_RW=`read_ini gv_rw`
  export GV_RW
  my_echo "GV_RW=$GV_RW"

  PATH=/sbin:/bin:/usr/bin:${GV_RO}bin/sesam:${GV_RO}bin/db:$PATH
  export PATH
  my_echo "PATH=$PATH"

  if [ "`uname`" = "OSF1" ]
  then
    LD_LIBRARY_PATH=${GV_RO}bin/db:/var/opt/DAU100/connect/lib
    TASO="-classic"
  else
    LD_LIBRARY_PATH=${GV_RO}bin/db
    TASO=""
  fi
  export LD_LIBRARY_PATH
  my_echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"

  #JAVA_CHECK=`java $TASO -version 2>&1 | grep 1.3`
  #if [ "$JAVA_CHECK" = "" ]
  #then
  #  echo "FAIL THERE IS NO JAVA 1.3.x. INSTALL FIRST"
  #  exit 1
  #fi

  ODBCINI=${GV_RW}var/ini/odbc.ini
  export ODBCINI
  my_echo "ODBCINI=$ODBCINI"

  OPENRDA_INI=${GV_RW}var/ini/openrda.ini
  export OPENRDA_INI
  my_echo "OPENRDA_INI=$OPENRDA_INI"

  #SEP=/
  #export SEP
  #my_echo "SEP=$SEP" 

  #OA_ROOT=${GV_RW}var/db
  #export OA_ROOT
  #my_echo "OA_ROOT=$OA_ROOT"
 
  MY_HOST=`read_ini gv_server`
  export MY_HOST
  my_echo "MY_HOST=$MY_HOST"
  
  MY_PORT=`read_ini gv_port_rmi`
  export MY_PORT
  my_echo "MY_PORT=$MY_PORT"

  if [ -f "${GV_RO}bin/gui/sm_rmigui.jar" ]
  then
    MY_CP="-classpath ./sm_rmigui.jar"
    MY_CMD=" -Djava.rmi.server.hostname=softnt14 -Djava.security.policy=/usr/sesam/var/ini/sm_java.policy de.sep.sesam.gui.tools.Ini2Defaults -u$ini_user -f sm_gui.ini -v1"
  fi
    
  cd ${GV_RO}bin/gui

  if [ "$VERBOSE_LEVEL" = "2" ] 
  then
    java $TASO -verbose $MY_CP $MY_CMD
  else
    java $TASO $MY_CP $MY_CMD
  fi

}
#
#
# START ini2defaults
if [ "$PROCESS_ALL" = "0" ]
then
   ini2defaults $USER
else
  GV_RW_INI=`read_ini gv_rw_ini`
  export GV_RW_INI
  my_echo "GV_RW_INI=$GV_RW_INI"
  {
  cd $GV_RW_INI
  for i in `ls` 
  do
     [ -d $GV_RW_INI/$i ] && ini2defaults $i
  done
  }
fi
